==> Botania-1.19.2-438-FABRIC-20230214.034242-11-sources.jar: vazkii/botania/client/render/block_entity/TEISR.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.client.render.block_entity;

import com.google.common.base.Preconditions;
import com.google.common.base.Suppliers;
import vazkii.botania.api.internal.ManaBurst;
import vazkii.botania.client.core.handler.ClientTickHandler;

import java.util.function.Supplier;
import net.minecraft.class_1799;
import net.minecraft.class_2248;
import net.minecraft.class_2343;
import net.minecraft.class_2586;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_809;
import net.minecraft.class_827;

public class TEISR {
	private final class_2248 block;
	private final Supplier<class_2586> dummy;

	public TEISR(class_2248 block) {
		Preconditions.checkArgument(block instanceof class_2343);
		this.block = block;
		this.dummy = Suppliers.memoize(() -> ((class_2343) block).method_10123(ManaBurst.NO_SOURCE, block.method_9564()));
	}

	public void render(class_1799 stack, class_809.class_811 mode, class_4587 ms, class_4597 buffers, int light, int overlay) {
		if (stack.method_31574(block.method_8389())) {
			class_827<?> r = class_310.method_1551().method_31975().method_3550(dummy.get());
			if (r != null) {
				r.method_3569(null, ClientTickHandler.partialTicks, ms, buffers, light, overlay);
			}
		}
	}
}

==> Botania-1.20.1-451-FABRIC-20251019.112919-17-sources.jar: vazkii/botania/client/render/block_entity/TEISR.java <==
/*
 * This class is distributed as part of the Botania Mod.
 * Get the Source Code in github:
 * https://github.com/Vazkii/Botania
 *
 * Botania is Open Source and distributed under the
 * Botania License: http://botaniamod.net/license.php
 */
package vazkii.botania.client.render.block_entity;

import com.google.common.base.Preconditions;
import com.google.common.base.Suppliers;
import vazkii.botania.api.internal.ManaBurst;
import vazkii.botania.client.core.handler.ClientTickHandler;

import java.util.function.Supplier;
import net.minecraft.class_1799;
import net.minecraft.class_2248;
import net.minecraft.class_2343;
import net.minecraft.class_2586;
import net.minecraft.class_310;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import net.minecraft.class_811;
import net.minecraft.class_827;

public class TEISR {
	private final class_2248 block;
	private final Supplier<class_2586> dummy;

	public TEISR(class_2248 block) {
		Preconditions.checkArgument(block instanceof class_2343);
		this.block = block;
		this.dummy = Suppliers.memoize(() -> ((class_2343) block).method_10123(ManaBurst.NO_SOURCE, block.method_9564()));
	}

	public void render(class_1799 stack, class_811 mode, class_4587 ms, class_4597 buffers, int light, int overlay) {
		if (stack.method_31574(block.method_8389())) {
			class_827<?> r = class_310.method_1551().method_31975().method_3550(dummy.get());
			if (r != null) {
				r.method_3569(null, ClientTickHandler.partialTicks, ms, buffers, light, overlay);
			}
		}
	}
}
